pub struct ContainerProbe {
pub exec: Option<ContainerExec>,
pub http_get: Option<ContainerHttpGet>,
pub initial_delay_seconds: Option<i32>,
pub period_seconds: Option<i32>,
pub failure_threshold: Option<i32>,
pub success_threshold: Option<i32>,
pub timeout_seconds: Option<i32>,
}Expand description
The container probe, for liveness or readiness
Fields
exec: Option<ContainerExec>The container execution command, for liveness or readiness probe
http_get: Option<ContainerHttpGet>The container Http Get settings, for liveness or readiness probe
initial_delay_seconds: Option<i32>The initial delay seconds.
period_seconds: Option<i32>The period seconds.
failure_threshold: Option<i32>The failure threshold.
success_threshold: Option<i32>The success threshold.
timeout_seconds: Option<i32>The timeout seconds.
Implementations