pub struct InitContainerPropertiesDefinition {
pub image: Option<String>,
pub command: Vec<String>,
pub environment_variables: Vec<EnvironmentVariable>,
pub instance_view: Option<InstanceView>,
pub volume_mounts: Vec<VolumeMount>,
pub security_context: Option<SecurityContextDefinition>,
}Expand description
The init container definition properties.
Fields
image: Option<String>The image of the init container.
command: Vec<String>The command to execute within the init container in exec form.
environment_variables: Vec<EnvironmentVariable>The environment variables to set in the init container.
instance_view: Option<InstanceView>The instance view of the init container. Only valid in response.
volume_mounts: Vec<VolumeMount>The volume mounts available to the init container.
security_context: Option<SecurityContextDefinition>The security context for the container.
Implementations