pub struct Client(/* private fields */);Implementations
Sourceimpl Client
impl Client
Sourcepub fn list_logs(
&self,
subscription_id: impl Into<String>,
resource_group_name: impl Into<String>,
container_group_name: impl Into<String>,
container_name: impl Into<String>,
) -> RequestBuilder
pub fn list_logs( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, container_group_name: impl Into<String>, container_name: impl Into<String>, ) -> RequestBuilder
Get the logs for a specified container instance. Get the logs for a specified container instance in a specified resource group and container group.
Arguments:
subscription_id: Subscription credentials which uniquely identify Microsoft Azure subscription. The subscription ID forms part of the URI for every service call.resource_group_name: The name of the resource group.container_group_name: The name of the container group.container_name: The name of the container instance.
Sourcepub fn execute_command(
&self,
subscription_id: impl Into<String>,
resource_group_name: impl Into<String>,
container_group_name: impl Into<String>,
container_name: impl Into<String>,
container_exec_request: impl Into<ContainerExecRequest>,
) -> RequestBuilder
pub fn execute_command( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, container_group_name: impl Into<String>, container_name: impl Into<String>, container_exec_request: impl Into<ContainerExecRequest>, ) -> RequestBuilder
Executes a command in a specific container instance. Executes a command for a specific container instance in a specified resource group and container group.
Arguments:
subscription_id: Subscription credentials which uniquely identify Microsoft Azure subscription. The subscription ID forms part of the URI for every service call.resource_group_name: The name of the resource group.container_group_name: The name of the container group.container_name: The name of the container instance.container_exec_request: The request for the exec command.
Sourcepub fn attach(
&self,
subscription_id: impl Into<String>,
resource_group_name: impl Into<String>,
container_group_name: impl Into<String>,
container_name: impl Into<String>,
) -> RequestBuilder
pub fn attach( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, container_group_name: impl Into<String>, container_name: impl Into<String>, ) -> RequestBuilder
Attach to the output of a specific container instance. Attach to the output stream of a specific container instance in a specified resource group and container group.
Arguments:
subscription_id: Subscription credentials which uniquely identify Microsoft Azure subscription. The subscription ID forms part of the URI for every service call.resource_group_name: The name of the resource group.container_group_name: The name of the container group.container_name: The name of the container instance.