pub struct ContainerProperties {
pub image: String,
pub command: Vec<String>,
pub ports: Vec<ContainerPort>,
pub environment_variables: Vec<EnvironmentVariable>,
pub instance_view: Option<InstanceView>,
pub resources: ResourceRequirements,
pub volume_mounts: Vec<VolumeMount>,
pub liveness_probe: Option<ContainerProbe>,
pub readiness_probe: Option<ContainerProbe>,
pub security_context: Option<SecurityContextDefinition>,
}Expand description
The container instance properties.
Fields
image: StringThe name of the image used to create the container instance.
command: Vec<String>The commands to execute within the container instance in exec form.
ports: Vec<ContainerPort>The exposed ports on the container instance.
environment_variables: Vec<EnvironmentVariable>The environment variables to set in the container instance.
instance_view: Option<InstanceView>The instance view of the container instance. Only valid in response.
resources: ResourceRequirementsThe resource requirements.
volume_mounts: Vec<VolumeMount>The volume mounts available to the container instance.
liveness_probe: Option<ContainerProbe>The container probe, for liveness or readiness
readiness_probe: Option<ContainerProbe>The container probe, for liveness or readiness
security_context: Option<SecurityContextDefinition>The security context for the container.
Implementations
Sourceimpl ContainerProperties
impl ContainerProperties
pub fn new(image: String, resources: ResourceRequirements) -> Self