Client

pub struct Client(/* private fields */);

Implementations

Source

impl Client

pub fn list(&self, subscription_id: impl Into<String>) -> RequestBuilder

Get a list of container groups in the specified subscription. Get a list of container groups in the specified subscription. This operation returns properties of each container group including containers, image registry credentials, restart policy, IP address type, OS type, state, and volumes.

Arguments:

  • subscription_id: The ID of the target subscription. The value must be an UUID.
pub fn list_by_resource_group( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, ) -> RequestBuilder

Get a list of container groups in the specified subscription and resource group. Get a list of container groups in a specified subscription and resource group. This operation returns properties of each container group including containers, image registry credentials, restart policy, IP address type, OS type, state, and volumes.

Arguments:

  • subscription_id: The ID of the target subscription. The value must be an UUID.
  • resource_group_name: The name of the resource group. The name is case insensitive.
pub fn get( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, container_group_name: impl Into<String>, ) -> RequestBuilder

Get the properties of the specified container group. Gets the properties of the specified container group in the specified subscription and resource group. The operation returns the properties of each container group including containers, image registry credentials, restart policy, IP address type, OS type, state, and volumes.

Arguments:

  • subscription_id: The ID of the target subscription. The value must be an UUID.
  • resource_group_name: The name of the resource group. The name is case insensitive.
  • container_group_name: The name of the container group.
pub fn create_or_update( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, container_group_name: impl Into<String>, container_group: impl Into<ContainerGroup>, ) -> RequestBuilder

Create or update container groups. Create or update container groups with specified configurations.

Arguments:

  • subscription_id: The ID of the target subscription. The value must be an UUID.
  • resource_group_name: The name of the resource group. The name is case insensitive.
  • container_group_name: The name of the container group.
  • container_group: The properties of the container group to be created or updated.
pub fn update( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, container_group_name: impl Into<String>, resource: impl Into<Resource>, ) -> RequestBuilder

Update container groups. Updates container group tags with specified values.

Arguments:

  • subscription_id: The ID of the target subscription. The value must be an UUID.
  • resource_group_name: The name of the resource group. The name is case insensitive.
  • container_group_name: The name of the container group.
  • resource: The container group resource with just the tags to be updated.
pub fn delete( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, container_group_name: impl Into<String>, ) -> RequestBuilder

Delete the specified container group. Delete the specified container group in the specified subscription and resource group. The operation does not delete other resources provided by the user, such as volumes.

Arguments:

  • subscription_id: The ID of the target subscription. The value must be an UUID.
  • resource_group_name: The name of the resource group. The name is case insensitive.
  • container_group_name: The name of the container group.
pub fn restart( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, container_group_name: impl Into<String>, ) -> RequestBuilder

Restarts all containers in a container group. Restarts all containers in a container group in place. If container image has updates, new image will be downloaded.

Arguments:

  • subscription_id: The ID of the target subscription. The value must be an UUID.
  • resource_group_name: The name of the resource group. The name is case insensitive.
  • container_group_name: The name of the container group.
pub fn stop( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, container_group_name: impl Into<String>, ) -> RequestBuilder

Stops all containers in a container group. Stops all containers in a container group. Compute resources will be deallocated and billing will stop.

Arguments:

  • subscription_id: The ID of the target subscription. The value must be an UUID.
  • resource_group_name: The name of the resource group. The name is case insensitive.
  • container_group_name: The name of the container group.
pub fn start( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, container_group_name: impl Into<String>, ) -> RequestBuilder

Starts all containers in a container group. Starts all containers in a container group. Compute resources will be allocated and billing will start.

Arguments:

  • subscription_id: The ID of the target subscription. The value must be an UUID.
  • resource_group_name: The name of the resource group. The name is case insensitive.
  • container_group_name: The name of the container group.
pub fn get_outbound_network_dependencies_endpoints( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, container_group_name: impl Into<String>, ) -> RequestBuilder

Get all network dependencies for container group. Gets all the network dependencies for this container group to allow complete control of network setting and configuration. For container groups, this will always be an empty list.

Arguments:

  • subscription_id: The ID of the target subscription. The value must be an UUID.
  • resource_group_name: The name of the resource group. The name is case insensitive.
  • container_group_name: The name of the container group.