pub struct GitRepoVolume {
pub directory: Option<String>,
pub repository: String,
pub revision: Option<String>,
}Expand description
Represents a volume that is populated with the contents of a git repository
Fields
directory: Option<String>Target directory name. Must not contain or start with ‘..’. If ‘.’ is supplied, the volume directory will be the git repository. Otherwise, if specified, the volume will contain the git repository in the subdirectory with the given name.
repository: StringRepository URL
revision: Option<String>Commit hash for the specified revision.
Implementations