pub struct Client(/* private fields */);Implementations
Sourceimpl Client
impl Client
Sourcepub fn get(
&self,
subscription_id: impl Into<String>,
resource_group_name: impl Into<String>,
ngroups_name: impl Into<String>,
) -> RequestBuilder
pub fn get( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, ngroups_name: impl Into<String>, ) -> RequestBuilder
Display information about a specified nGroup. Get the properties of the specified n group.
Arguments:
subscription_id: Subscription credentials which uniquely identify Microsoft Azure subscription. The subscription ID forms part of the URI for every service call.resource_group_name: The name of the resource group.ngroups_name: The N Groups name.
Sourcepub fn create_or_update(
&self,
resource_group_name: impl Into<String>,
ngroups_name: impl Into<String>,
n_group: impl Into<NGroup>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn create_or_update( &self, resource_group_name: impl Into<String>, ngroups_name: impl Into<String>, n_group: impl Into<NGroup>, subscription_id: impl Into<String>, ) -> RequestBuilder
Create or update a nGroup.
Arguments:
resource_group_name: The name of the resource group.ngroups_name: The N Groups name.n_group: The nGroup object.subscription_id: Subscription credentials which uniquely identify Microsoft Azure subscription. The subscription ID forms part of the URI for every service call.
Sourcepub fn update(
&self,
resource_group_name: impl Into<String>,
ngroups_name: impl Into<String>,
parameters: impl Into<NGroup>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn update( &self, resource_group_name: impl Into<String>, ngroups_name: impl Into<String>, parameters: impl Into<NGroup>, subscription_id: impl Into<String>, ) -> RequestBuilder
Update a specified nGroup. Update a specified nGroup.
Arguments:
resource_group_name: The name of the resource group.ngroups_name: The N Groups name.parameters: The nGroup object.subscription_id: Subscription credentials which uniquely identify Microsoft Azure subscription. The subscription ID forms part of the URI for every service call.
Sourcepub fn delete(
&self,
resource_group_name: impl Into<String>,
ngroups_name: impl Into<String>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn delete( &self, resource_group_name: impl Into<String>, ngroups_name: impl Into<String>, subscription_id: impl Into<String>, ) -> RequestBuilder
Delete a nGroup. Deletes a nGroup.
Arguments:
resource_group_name: The name of the resource group.ngroups_name: The N Groups name.subscription_id: Subscription credentials which uniquely identify Microsoft Azure subscription. The subscription ID forms part of the URI for every service call.
Sourcepub fn start(
&self,
subscription_id: impl Into<String>,
resource_group_name: impl Into<String>,
ngroups_name: impl Into<String>,
) -> RequestBuilder
pub fn start( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, ngroups_name: impl Into<String>, ) -> RequestBuilder
Starts all container groups in a nGroup. Starts all container groups in a nGroup. Compute resources will be allocated and billing will start.
Arguments:
subscription_id: Subscription credentials which uniquely identify Microsoft Azure subscription. The subscription ID forms part of the URI for every service call.resource_group_name: The name of the resource group.ngroups_name: The N Groups name.
Sourcepub fn stop(
&self,
subscription_id: impl Into<String>,
resource_group_name: impl Into<String>,
ngroups_name: impl Into<String>,
) -> RequestBuilder
pub fn stop( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, ngroups_name: impl Into<String>, ) -> RequestBuilder
Stops all container groups in a nGroup. Stops all container groups in a nGroup. Compute resources will be deallocated and billing will stop.
Arguments:
subscription_id: Subscription credentials which uniquely identify Microsoft Azure subscription. The subscription ID forms part of the URI for every service call.resource_group_name: The name of the resource group.ngroups_name: The N Groups name.
Sourcepub fn restart(
&self,
subscription_id: impl Into<String>,
resource_group_name: impl Into<String>,
ngroups_name: impl Into<String>,
) -> RequestBuilder
pub fn restart( &self, subscription_id: impl Into<String>, resource_group_name: impl Into<String>, ngroups_name: impl Into<String>, ) -> RequestBuilder
Restarts all container groups in a nGroup. Restarts all container groups in a nGroup in place. If container image has updates, new image will be downloaded.
Arguments:
subscription_id: Subscription credentials which uniquely identify Microsoft Azure subscription. The subscription ID forms part of the URI for every service call.resource_group_name: The name of the resource group.ngroups_name: The N Groups name.
Sourcepub fn list_by_resource_group(
&self,
resource_group_name: impl Into<String>,
subscription_id: impl Into<String>,
) -> RequestBuilder
pub fn list_by_resource_group( &self, resource_group_name: impl Into<String>, subscription_id: impl Into<String>, ) -> RequestBuilder
Gets a list of all nGroups under a resource group. Gets a list of all nGroups under a resource group.
Arguments:
resource_group_name: The name of the resource group.subscription_id: Subscription credentials which uniquely identify Microsoft Azure subscription. The subscription ID forms part of the URI for every service call.
Sourcepub fn list(&self, subscription_id: impl Into<String>) -> RequestBuilder
pub fn list(&self, subscription_id: impl Into<String>) -> RequestBuilder
Gets a list of all nGroups under a subscription. Gets a list of all nGroups under a subscription.
Arguments:
subscription_id: Subscription credentials which uniquely identify Microsoft Azure subscription. The subscription ID forms part of the URI for every service call.