pub struct ContainerAttachResponse {
pub web_socket_uri: Option<String>,
pub password: Option<String>,
}Expand description
The information for the output stream from container attach.
Fields
web_socket_uri: Option<String>The uri for the output stream from the attach.
password: Option<String>The password to the output stream from the attach. Send as an Authorization header value when connecting to the websocketUri.
Implementations